@@ -141,6 +141,11 @@ data = {
                         "help": "choose type of prerelease",
                         "choices": ["alpha", "beta", "rc"],
                     },
+                    {
+                        "name": ["--devrelease", "-d"],
+                        "help": "specify non-negative integer for dev. release",
+                        "type": int,
+                    },
                     {
                         "name": ["--increment"],
                         "help": "manually specify the desired increment",
